View source: R/plot_layout_dataframe.R
| plot_layout_dataframe | R Documentation |
This function recive dataframe similar to the output from read_layout_files() and generate a plot that represents the designed layout of the microplate.
plot_layout_dataframe( platemap_df, var_shape, var_colour, add_conc = NULL, plate_title = NULL )
platemap_df |
dataframe structure similar to read_layout_files() output |
var_shape |
Assign shape to represent one variable |
var_colour |
Assign colour to other variable |
add_conc |
This argument is optional, TRUE to add concentration. |
plate_title |
This argument is optional, add the title. |
Returns a plot that represents the microplate with the given layout. The plot shows in the x-axis the number of columns and in the y-axis the letter to identified the row.
file_path <- system.file("extdata", "test_layout_file.csv",
package = "mpxtractor"
)
# Data is store as a tibble
df_plot_plate <- read_layout_file( file = file_path)
plot_plate <- plot_layout_dataframe(
df_plot_plate,
var_shape = "basic",
var_colour = "condition",
plate_title = "My experiment"
)
# Show the plot
plot_plate
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.