View source: R/plot_layout_file.R
| plot_layout_file | R Documentation |
This function recive one file which is the .csv layout file and generate a plot that represents the designed layout of the microplate.
plot_layout_file( file, var_shape = NULL, var_colour = NULL, add_conc = FALSE, plate_title = NULL, output_filename )
file |
The path to a proper .csv layout file. |
var_shape |
Assign shape to represent one variable |
var_colour |
Assign colour to other variable |
add_conc |
This argument is optional, TRUE to add concentration. |
plate_title |
This argument is optional, add the title. |
output_filename |
The name of the output file followed by propoer extension, ie. .png |
Returns a plot that represents the microplate with the given layout. The plot shows in the x-axis the number of columns and in the y-axis the letter to identified the row.
file formatNote that the .csv layout file needs to be formatted in the correct way. See files in the examples below.
file_path <- system.file("extdata", "test_layout_file.csv",
package = "mpxtractor"
)
# Data is store as a tibble
plot_plate <- plot_layout_file(
file = file_path,
var_shape = "basic",
var_colour = "condition",
add_conc = TRUE,
plate_title = "My experiment",
output_filename = "example.png"
)
# Show the plot
plot_plate
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.